

class {{ cookiecutter.behavior_name }}ModelUI(object):
    """ ModelUI marker for {{ cookiecutter.behavior_name }}"""
    pass

class {{ cookiecutter.behavior_name }}CollectionUI(object):
    """ Collection UI marker for {{ cookiecutter.behavior_name }}"""
    pass
