
class {{ cookiecutter.behavior_name }}Model(object):
    """ Model marker for {{ cookiecutter.behavior_name }}"""
    pass


class {{ cookiecutter.behavior_name }}Collection(object):
    """ Collection marker for {{ cookiecutter.behavior_name }}"""
    pass

